@@ -47,7 +47,7 @@ def build_grai_metadata_from_column(current: Column, version: Literal["v1"] = "v
         "node_attributes": {
             "data_type": current.data_type,
             "default_value": default_value,
-            "is_nullable": current.is_nullable,
+            "is_nullable": None if current.is_nullable else False,  # Only not-nullable is definitive.
             "is_primary_key": current.column_key.value == ColumnKey.PRIMARY_KEY.value,
             "is_unique": current.column_key.value in UNIQUE_COLUMN_CONSTRAINTS,
         },
